@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2016-02-26'; # DATE
-our $VERSION = '0.56'; # VERSION
+our $DATE = '2016-03-26'; # DATE
+our $VERSION = '0.57'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -17,6 +17,7 @@ use Perinci::Access::Perl;
 use Perinci::Sub::To::CLIDocData qw(gen_cli_doc_data_from_meta);
 use Perinci::To::POD;
 use Scalar::Util qw(blessed);
+use Sub::Identify qw(sub_fullname);
 
 our $pa = Perinci::Access::Perl->new;
 
@@ -55,7 +56,14 @@ sub _process_module {
     my $exports = {};
     {
         no strict 'refs';
-        $package->import;
+
+        # we import specifically when module is using Exporter::Rinci as its
+        # exporter, because Exporter::Rinci works by filling @EXPORT* variables
+        # during import().
+        if (sub_fullname(\&{"$package\::import"}) =~ /^Exporter::Rinci::/) {
+            $package->import;
+        }
+
         my $uses_exporter_mod = @{"$package\::EXPORT"} || @{"$package\::EXPORT_OK"};
         for my $funcname (keys %$cmetas) {
             next unless $funcname =~ /\A\w+\z/;
@@ -791,7 +799,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.56 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2016-02-26.
+This document describes version 0.57 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2016-03-26.
 
 =head1 SYNOPSIS
 
